@@ -2,7 +2,7 @@
 // async_udp_echo_server.cpp
 // ~~~~~~~~~~~~~~~~~~~~~~~~~
 //
-// Copyright (c) 2003-2008 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2011 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -50,7 +50,8 @@ public:
     }
   }
 
-  void handle_send_to(const asio::error_code& error, size_t bytes_sent)
+  void handle_send_to(const asio::error_code& /*error*/,
+      size_t /*bytes_sent*/)
   {
     socket_.async_receive_from(
         asio::buffer(data_, max_length), sender_endpoint_,
