@@ -2,7 +2,7 @@
 // stream_client.cpp
 // ~~~~~~~~~~~~~~~~~
 //
-// Copyright (c) 2003-2008 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2011 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -28,10 +28,13 @@ int main(int argc, char* argv[])
       return 1;
     }
 
-    asio::io_service io_service;
-
     stream_protocol::endpoint ep(argv[1]);
     stream_protocol::iostream s(ep);
+    if (!s)
+    {
+      std::cerr << "Unable to connect\n";
+      return 1;
+    }
 
     using namespace std; // For strlen.
     std::cout << "Enter message: ";
