@@ -2,7 +2,7 @@
 // unicast.cpp
 // ~~~~~~~~~~~
 //
-// Copyright (c) 2003-2008 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2011 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -16,7 +16,8 @@
 // Test that header file is self-contained.
 #include "asio/ip/unicast.hpp"
 
-#include "asio.hpp"
+#include "asio/io_service.hpp"
+#include "asio/ip/udp.hpp"
 #include "../unit_test.hpp"
 
 //------------------------------------------------------------------------------
@@ -45,7 +46,7 @@ void test()
     ip::unicast::hops hops2;
     sock.get_option(hops2);
     hops1 = 1;
-    static_cast<int>(hops1.value());
+    (void)static_cast<int>(hops1.value());
   }
   catch (std::exception&)
   {
