@@ -2,7 +2,7 @@
 // socket_base.cpp
 // ~~~~~~~~~~~~~~~
 //
-// Copyright (c) 2003-2008 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2011 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -16,7 +16,9 @@
 // Test that header file is self-contained.
 #include "asio/socket_base.hpp"
 
-#include "asio.hpp"
+#include "asio/io_service.hpp"
+#include "asio/ip/tcp.hpp"
+#include "asio/ip/udp.hpp"
 #include "unit_test.hpp"
 
 //------------------------------------------------------------------------------
@@ -58,9 +60,9 @@ void test()
     socket_base::broadcast broadcast2;
     sock.get_option(broadcast2);
     broadcast1 = true;
-    static_cast<bool>(broadcast1);
-    static_cast<bool>(!broadcast1);
-    static_cast<bool>(broadcast1.value());
+    (void)static_cast<bool>(broadcast1);
+    (void)static_cast<bool>(!broadcast1);
+    (void)static_cast<bool>(broadcast1.value());
 
     // debug class.
 
@@ -69,9 +71,9 @@ void test()
     socket_base::debug debug2;
     sock.get_option(debug2);
     debug1 = true;
-    static_cast<bool>(debug1);
-    static_cast<bool>(!debug1);
-    static_cast<bool>(debug1.value());
+    (void)static_cast<bool>(debug1);
+    (void)static_cast<bool>(!debug1);
+    (void)static_cast<bool>(debug1.value());
 
     // do_not_route class.
 
@@ -80,9 +82,9 @@ void test()
     socket_base::do_not_route do_not_route2;
     sock.get_option(do_not_route2);
     do_not_route1 = true;
-    static_cast<bool>(do_not_route1);
-    static_cast<bool>(!do_not_route1);
-    static_cast<bool>(do_not_route1.value());
+    (void)static_cast<bool>(do_not_route1);
+    (void)static_cast<bool>(!do_not_route1);
+    (void)static_cast<bool>(do_not_route1.value());
 
     // keep_alive class.
 
@@ -91,9 +93,9 @@ void test()
     socket_base::keep_alive keep_alive2;
     sock.get_option(keep_alive2);
     keep_alive1 = true;
-    static_cast<bool>(keep_alive1);
-    static_cast<bool>(!keep_alive1);
-    static_cast<bool>(keep_alive1.value());
+    (void)static_cast<bool>(keep_alive1);
+    (void)static_cast<bool>(!keep_alive1);
+    (void)static_cast<bool>(keep_alive1.value());
 
     // send_buffer_size class.
 
@@ -102,7 +104,7 @@ void test()
     socket_base::send_buffer_size send_buffer_size2;
     sock.get_option(send_buffer_size2);
     send_buffer_size1 = 1;
-    static_cast<int>(send_buffer_size1.value());
+    (void)static_cast<int>(send_buffer_size1.value());
 
     // send_low_watermark class.
 
@@ -111,7 +113,7 @@ void test()
     socket_base::send_low_watermark send_low_watermark2;
     sock.get_option(send_low_watermark2);
     send_low_watermark1 = 1;
-    static_cast<int>(send_low_watermark1.value());
+    (void)static_cast<int>(send_low_watermark1.value());
 
     // receive_buffer_size class.
 
@@ -120,7 +122,7 @@ void test()
     socket_base::receive_buffer_size receive_buffer_size2;
     sock.get_option(receive_buffer_size2);
     receive_buffer_size1 = 1;
-    static_cast<int>(receive_buffer_size1.value());
+    (void)static_cast<int>(receive_buffer_size1.value());
 
     // receive_low_watermark class.
 
@@ -129,7 +131,7 @@ void test()
     socket_base::receive_low_watermark receive_low_watermark2;
     sock.get_option(receive_low_watermark2);
     receive_low_watermark1 = 1;
-    static_cast<int>(receive_low_watermark1.value());
+    (void)static_cast<int>(receive_low_watermark1.value());
 
     // reuse_address class.
 
@@ -138,9 +140,9 @@ void test()
     socket_base::reuse_address reuse_address2;
     sock.get_option(reuse_address2);
     reuse_address1 = true;
-    static_cast<bool>(reuse_address1);
-    static_cast<bool>(!reuse_address1);
-    static_cast<bool>(reuse_address1.value());
+    (void)static_cast<bool>(reuse_address1);
+    (void)static_cast<bool>(!reuse_address1);
+    (void)static_cast<bool>(reuse_address1.value());
 
     // linger class.
 
@@ -149,9 +151,9 @@ void test()
     socket_base::linger linger2;
     sock.get_option(linger2);
     linger1.enabled(true);
-    static_cast<bool>(linger1.enabled());
+    (void)static_cast<bool>(linger1.enabled());
     linger1.timeout(1);
-    static_cast<int>(linger1.timeout());
+    (void)static_cast<int>(linger1.timeout());
 
     // enable_connection_aborted class.
 
@@ -160,9 +162,9 @@ void test()
     socket_base::enable_connection_aborted enable_connection_aborted2;
     sock.get_option(enable_connection_aborted2);
     enable_connection_aborted1 = true;
-    static_cast<bool>(enable_connection_aborted1);
-    static_cast<bool>(!enable_connection_aborted1);
-    static_cast<bool>(enable_connection_aborted1.value());
+    (void)static_cast<bool>(enable_connection_aborted1);
+    (void)static_cast<bool>(!enable_connection_aborted1);
+    (void)static_cast<bool>(enable_connection_aborted1.value());
 
     // non_blocking_io class.
 
